@@ -14,6 +14,7 @@ log = logging.getLogger('ipc')
 
 # Allow some attributes from dict interface to be called over the wire
 rpyc.core.protocol.DEFAULT_CONFIG['safe_attrs'].update(['items'])
+rpyc.core.protocol.DEFAULT_CONFIG['allow_pickle'] = True
 
 IPC_VERSION = 0
 AUTH_ERROR = 'authentication error'
@@ -35,7 +36,7 @@ class DaemonService(rpyc.Service):
     def exposed_execute(self, options=None):
         # Dictionaries are pass by reference with rpyc, turn this into a real dict on our side
         if options:
-            options = dict(options.items())
+            options = rpyc.utils.classic.obtain(options)
         if self.manager.scheduler.run_queue.qsize() > 0:
             self.client_console('There is already a task executing. This task will execute next.')
         log.info('Executing for client.')
