@@ -2,8 +2,9 @@ from __future__ import unicode_literals, division, absolute_import
 import os
 import logging
 
+from flexget import plugin
+from flexget.event import event
 from flexget.config_schema import one_or_more
-from flexget.plugin import register_plugin, priority, PluginWarning
 
 log = logging.getLogger('exists')
 
@@ -20,25 +21,24 @@ class FilterExists(object):
 
     schema = one_or_more({'type': 'string', 'format': 'path'})
 
-    def get_config(self, task):
-        config = task.config.get('exists', None)
+    def prepare_config(self, config):
         # If only a single path is passed turn it into a 1 element list
         if isinstance(config, basestring):
             config = [config]
         return config
 
-    @priority(-1)
-    def on_task_filter(self, task):
+    @plugin.priority(-1)
+    def on_task_filter(self, task, config):
         if not task.accepted:
             log.debug('No accepted entries, not scanning for existing.')
             return
         log.verbose('Scanning path(s) for existing files.')
-        config = self.get_config(task)
+        config = self.prepare_config(config)
         for path in config:
             # unicode path causes crashes on some paths
             path = str(os.path.expanduser(path))
             if not os.path.exists(path):
-                raise PluginWarning('Path %s does not exist' % path, log)
+                raise plugin.PluginWarning('Path %s does not exist' % path, log)
             # scan through
             for root, dirs, files in os.walk(path, followlinks=True):
                 # convert filelists into utf-8 to avoid unicode problems
@@ -50,4 +50,6 @@ class FilterExists(object):
                         log.debug('Found %s in %s' % (name, root))
                         entry.reject(os.path.join(root, name))
 
-register_plugin(FilterExists, 'exists')
+@event('plugin.register')
+def register_plugin():
+    plugin.register(FilterExists, 'exists', api_ver=2)
